aboutsummaryrefslogtreecommitdiff
path: root/src/modules
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules')
-rw-r--r--src/modules/company/index.ts11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/modules/company/index.ts b/src/modules/company/index.ts
index 1dce91fd..d98eb89e 100644
--- a/src/modules/company/index.ts
+++ b/src/modules/company/index.ts
@@ -29,7 +29,7 @@ export class Company {
/**
* Generates a random company name.
*
* @param format The optional format index used to select a format.
*
* @example
* faker.company.name() // 'Zieme, Hauck and McClure'
@@ -41,6 +41,15 @@ export class Company {
'{{name.lastName}}, {{name.lastName}} and {{name.lastName}}',
];
+ if (format != null) {
+ deprecated({
+ deprecated: 'faker.company.name(format)',
+ proposed: 'faker.company.name()',
+ since: '7.4',
+ until: '8.0',
+ });
+ }
+
if (typeof format !== 'number') {
format = this.faker.datatype.number(formats.length - 1);
}
@@ -29,7 +29,7 @@ export class Company {
* Generates a random company name.
*
- * @param format The optional format index used to select a format.
+ * @param format The optional format index used to select a format. Deprecated, do not use.
*
* @example